@@ -10,9 +10,10 @@ use Class::Usul::Constants qw( BRK FAILED FALSE NUL OK
                                SPC TRUE UNDEFINED_RV WIDTH );
 use Class::Usul::File;
 use Class::Usul::Functions qw( abs_path elapsed emit emit_err emit_to
-                               exception find_apphome find_source
-                               get_cfgfiles is_arrayref is_hashref is_member
-                               logname pad throw untaint_cmdline );
+                               ensure_class_loaded env_prefix exception
+                               find_apphome find_source get_cfgfiles
+                               is_arrayref is_hashref is_member logname pad
+                               throw untaint_cmdline );
 use Class::Usul::IPC;
 use Class::Usul::Options;
 use Class::Usul::Types     qw( ArrayRef Bool EncodingType FileType HashRef
@@ -30,13 +31,118 @@ use Try::Tiny;
 extends q(Class::Usul);
 with    q(Class::Usul::TraitFor::Prompting);
 
+# Private functions
+my $_dash2underscore = sub {
+   (my $x = $_[ 0 ] || NUL) =~ s{ [\-] }{_}gmx; return $x;
+};
+
+my $_get_pod_content_for_attr = sub {
+   my ($class, $attr) = @_; my $pod;
+
+   my $src    = find_source $class
+      or throw 'Class [_1] cannot find source', [ $class ];
+   my $events = Pod::Eventual::Simple->read_file( $src );
+
+   for (my $ev_no = 0, my $max = @{ $events }; $ev_no < $max; $ev_no++) {
+      my $ev = $events->[ $ev_no ]; $ev->{type} eq 'command' or next;
+
+      $ev->{content} =~ m{ (?: ^|[< ]) $attr (?: [ >]|$ ) }msx or next;
+
+      $ev_no++ while ($ev = $events->[ $ev_no + 1 ] and $ev->{type} eq 'blank');
+
+      $ev and $ev->{type} eq 'text' and $pod = $ev->{content} and last;
+   }
+
+   $pod //= 'Undocumented'; $pod and chomp $pod; $pod =~ s{ [\n] }{ }gmx;
+
+   return $pod;
+};
+
+my $_get_pod_header_for_method = sub {
+   my ($class, $method) = @_;
+
+   my $src = find_source $class
+      or throw 'Class [_1] cannot find source', [ $class ];
+   my $pod = Pod::Eventual::Simple->read_file( $src );
+   my $out = [ grep { $_->{content} =~ m{ (?: ^|[< ]) $method (?: [ >]|$ ) }msx}
+               grep { $_->{type} eq 'command' } @{ $pod } ]->[ 0 ]->{content};
+
+   $out and chomp $out;
+   return $out;
+};
+
+my $_list_attr_of = sub {
+   my ($obj, @except) = @_; my $class = blessed $obj;
+
+   ensure_class_loaded 'Pod::Eventual::Simple';
+
+   return map  { my $attr = $_->[0]; [ @{ $_ }, $obj->$attr ] }
+          map  { [ $_->[1], $_->[0], $_get_pod_content_for_attr->( @{ $_ } ) ] }
+          grep { $_->[0] ne 'Moo::Object' and not is_member $_->[1], @except }
+          map  { m{ \A (.+) \:\: ([^:]+) \z }mx; [ $1, $2 ] }
+              @{ Class::Inspector->methods( $class, 'full', 'public' ) };
+};
+
+my $_list_methods_of = sub {
+   return map  { s{ \A .+ :: }{}msx; $_ }
+          grep { my $subr = $_;
+                 grep { $_ eq 'method' } attributes::get( \&{ $subr } ) }
+              @{ Class::Inspector->methods
+                    ( blessed $_[ 0 ] || $_[ 0 ], 'full', 'public' ) };
+};
+
+my $_output_stacktrace = sub {
+   my ($e, $verbose) = @_; ($e and blessed $e) or return; $verbose //= 0;
+
+   $verbose > 0 and $e->can( 'trace' )
+      and return emit_to \*STDERR, NUL.$e->trace;
+
+   $e->can( 'stacktrace' ) and emit_to \*STDERR, NUL.$e->stacktrace;
+
+   return;
+};
+
+# Construction methods
+my $_build_debug = sub {
+   my $self = shift; my $k = (env_prefix $self->config->appclass).'_DEBUG';
+
+   return !!$ENV{ $k } ? TRUE : FALSE;
+};
+
+my $_build_os = sub {
+   my $self = shift;
+   my $file = 'os_'.$Config{osname}.$self->config->extension;
+   my $path = $self->config->ctrldir->catfile( $file );
+
+   $path->exists or return {};
+
+   my $cfg  = $self->file->data_load( paths => [ $path ] );
+
+   return $cfg->{os} || {};
+};
+
+my $_build_run_method = sub {
+   my $self = shift; my $method = $_dash2underscore->( $self->method );
+
+   unless ($self->can_call( $method )) {
+      $method = $_dash2underscore->( $self->extra_argv( 0 ) );
+      $method = $self->can_call( $method )
+              ? $_dash2underscore->( $self->next_argv ) : NUL;
+   }
+
+   $method ||= 'run_chain';
+  ($method eq 'help' or $method eq 'run_chain') and $self->quiet( TRUE );
+
+   return $self->_set_method( $method );
+};
+
 # Override attributes in base class
-has '+config_class'   => default => sub { 'Class::Usul::Config::Programs' };
+has '+config_class'   => default => 'Class::Usul::Config::Programs';
 
 # Public attributes
-option 'debug'        => is => 'rwp',  isa => Bool, default => FALSE,
+option 'debug'        => is => 'rwp',  isa => Bool, builder => $_build_debug,
    documentation      => 'Turn debugging on. Prompts if interactive',
-   short              => 'D';
+   short              => 'D', lazy => TRUE;
 
 option 'encoding'     => is => 'lazy', isa => EncodingType, format => 's',
    documentation      => 'Decode/encode input/output using this encoding',
@@ -104,53 +210,17 @@ has '_ipc'        => is => 'lazy', isa => IPCType,
    builder        => sub { Class::Usul::IPC->new( builder => $_[ 0 ] ) },
    handles        => [ qw( run_cmd ) ], init_arg => undef, reader => 'ipc';
 
-has '_os'         => is => 'lazy', isa => HashRef, init_arg => undef,
-   reader         => 'os';
+has '_os'         => is => 'lazy', isa => HashRef,
+   builder        => $_build_os, init_arg => undef, reader => 'os';
 
 has '_quiet_flag' => is => 'rw',   isa => Bool,
-   default        => sub { $_[ 0 ]->quiet_flag },
+   builder        => sub { $_[ 0 ]->quiet_flag },
    init_arg       => 'quiet', lazy => TRUE, writer => '_set__quiet_flag';
 
-has '_run_method' => is => 'lazy', isa => SimpleStr, init_arg => undef,
+has '_run_method' => is => 'lazy', isa => SimpleStr,
+   builder        => $_build_run_method, init_arg => undef,
    reader         => 'run_method';
 
-# Private functions
-my $_dash2underscore = sub {
-   (my $x = $_[ 0 ] || NUL) =~ s{ [\-] }{_}gmx; return $x;
-};
-
-my $_get_pod_header_for_method = sub {
-   my ($class, $method) = @_;
-
-   my $src = find_source $class
-      or throw 'Class [_1] cannot find source', [ $class ];
-   my $pod = Pod::Eventual::Simple->read_file( $src );
-   my $out = [ grep { $_->{content} =~ m{ (?: ^|[< ]) $method (?: [ >]|$ ) }msx}
-               grep { $_->{type} eq 'command' } @{ $pod } ]->[ 0 ]->{content};
-
-   $out and chomp $out;
-   return $out;
-};
-
-my $_list_methods_of = sub {
-   return map  { s{ \A .+ :: }{}msx; $_ }
-          grep { my $subr = $_;
-                 grep { $_ eq 'method' } attributes::get( \&{ $subr } ) }
-              @{ Class::Inspector->methods
-                    ( blessed $_[ 0 ] || $_[ 0 ], 'full', 'public' ) };
-};
-
-my $_output_stacktrace = sub {
-   my ($e, $verbose) = @_; ($e and blessed $e) or return; $verbose //= 0;
-
-   $verbose > 0 and $e->can( 'trace' )
-      and return emit_to \*STDERR, NUL.$e->trace;
-
-   $e->can( 'stacktrace' ) and emit_to \*STDERR, NUL.$e->stacktrace;
-
-   return;
-};
-
 # Private methods
 my $_apply_stdio_encoding = sub {
    my $self = shift; my $enc = $self->encoding;
@@ -179,12 +249,11 @@ my $_catch_run_exception = sub {
 };
 
 my $_dont_ask = sub {
-   return $_[ 0 ]->debug || $_[ 0 ]->help_usage || $_[ 0 ]->help_options
-       || $_[ 0 ]->help_manual || ! $_[ 0 ]->is_interactive();
+   return $_[ 0 ]->debug || ! $_[ 0 ]->is_interactive();
 };
 
 my $_get_classes_and_roles = sub {
-   my $self = shift; my %uniq = (); require mro;
+   my $self = shift; my %uniq = (); ensure_class_loaded 'mro';
 
    my @classes = @{ mro::get_linear_isa( blessed $self ) };
 
@@ -220,7 +289,9 @@ my $_exit_version = sub {
 };
 
 my $_man_page_from = sub {
-   my ($self, $src) = @_; my $cfg = $self->config; require Pod::Man;
+   my ($self, $src) = @_; my $cfg = $self->config;
+
+   ensure_class_loaded 'Pod::Man';
 
    my $parser   = Pod::Man->new( center  => $cfg->doc_title || NUL,
                                  name    => $cfg->script,
@@ -235,14 +306,12 @@ my $_man_page_from = sub {
 };
 
 my $_usage_for = sub {
-   my ($self, $method) = @_;
+   my ($self, $method) = @_; ensure_class_loaded 'Pod::Select';
 
    for my $class (@{ $self->$_get_classes_and_roles }) {
       is_member( $method, Class::Inspector->methods( $class, 'public' ) )
          or next;
 
-      require Pod::Select;
-
       my $selector = Pod::Select->new(); my $tfile = $self->file->tempfile;
 
       $selector->select( "/(?:[A-Z][\<])?${method}.*" );
@@ -262,7 +331,7 @@ my $_output_usage = sub {
 
    $verbose > 1 and return $self->$_man_page_from( $self->config );
 
-   require Pod::Usage; $verbose > 0 and Pod::Usage::pod2usage
+   ensure_class_loaded 'Pod::Usage'; $verbose > 0 and Pod::Usage::pod2usage
       ( { -exitval => OK,
           -input   => NUL.$self->config->pathname,
           -message => SPC,
@@ -301,33 +370,6 @@ sub BUILD {
    return;
 }
 
-sub _build__os {
-   my $self = shift;
-   my $file = 'os_'.$Config{osname}.$self->config->extension;
-   my $path = $self->config->ctrldir->catfile( $file );
-
-   $path->exists or return {};
-
-   my $cfg  = $self->file->data_load( paths => [ $path ] );
-
-   return $cfg->{os} || {};
-}
-
-sub _build__run_method {
-   my $self = shift; my $method = $_dash2underscore->( $self->method );
-
-   unless ($self->can_call( $method )) {
-      $method = $_dash2underscore->( $self->extra_argv( 0 ) );
-      $method = $self->can_call( $method )
-              ? $_dash2underscore->( $self->next_argv ) : NUL;
-   }
-
-   $method ||= 'run_chain';
-  ($method eq 'help' or $method eq 'run_chain') and $self->quiet( TRUE );
-
-   return $self->_set_method( $method );
-}
-
 # Public methods
 sub add_leader {
    my ($self, $text, $args) = @_; $text or return NUL; $args ||= {};
@@ -357,6 +399,15 @@ sub debug_flag {
    return $_[ 0 ]->debug ? '-D' : '-n';
 }
 
+sub dump_config_attr : method {
+   my $self = shift; my @except =
+      qw( BUILDARGS BUILD inflate_path inflate_paths inflate_symbol new secret);
+
+   $self->dumper( [ $_list_attr_of->( $self->config, @except ) ] );
+
+   return OK;
+}
+
 sub dump_self : method {
    my $self = shift;
 
@@ -416,7 +467,7 @@ sub interpolate_cmd {
 }
 
 sub list_methods : method {
-   my $self = shift; require Pod::Eventual::Simple;
+   my $self = shift; ensure_class_loaded 'Pod::Eventual::Simple';
 
    my $abstract = {}; my $max = 0; my $classes = $self->$_get_classes_and_roles;
 
@@ -665,6 +716,13 @@ the I<method> method attribute
 
 Returns the command line debug flag to match the current debug state
 
+=head2 dump_config_attr - Dumps the configuration attributes and values
+
+   $self->dump_config_attr;
+
+Visits the configuration object, forcing evaluation of the lazy, and printing
+out the attributes and values
+
 =head2 dump_self - Dumps the program object
 
    $self->dump_self;
